@@ -2,7 +2,7 @@ package HTML::TableContent::Parser;
 
 use Moo;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 extends 'HTML::Parser';
 
@@ -12,20 +12,18 @@ use HTML::TableContent::Table::Row;
 use HTML::TableContent::Table::Row::Cell;
 use HTML::TableContent::Table::Caption;
 
-has current_tables => (
+has [qw(current_tables nested)] => (
     is      => 'rw',
     lazy    => 1,
     clearer => 1,
     default => sub { [] },
 );
 
-has [
-    qw(current_table current_caption current_row current_header current_cell current_element)
-  ] => (
+has [qw(current_table current_element)] => (
     is      => 'rw',
     lazy    => 1,
     clearer => 1,
-  );
+);
 
 has options => (
     is      => 'ro',
@@ -33,68 +31,42 @@ has options => (
     builder => 1,
 );
 
-sub _build_options {
-    return {
-        table => {
-            class       => 'Table',
-            store       => [qw/current_table/],
-            push_action => '_push_table',
-            clear       => [
-                qw/current_table current_row current_cell current_header current_element/
-            ],
-        },
-        th => {
-            class       => 'Table::Header',
-            store       => [qw/current_header current_element/],
-            push_action => '_push_header',
-            clear =>
-              [qw/current_row current_cell current_header current_element/],
-        },
-        tr => {
-            class       => 'Table::Row',
-            store       => [qw/current_row current_element/],
-            push_action => '_push_row',
-            clear =>
-              [qw/current_row current_cell current_header current_element/],
-        },
-        td => {
-            class       => 'Table::Row::Cell',
-            store       => [qw/current_cell current_element/],
-            push_action => '_push_cell',
-            clear       => [qw/current_cell current_header current_element/],
-        },
-        caption => {
-            class       => 'Table::Caption',
-            store       => [qw/current_element/],
-            push_action => '_push_caption',
-            clear       => [qw/current_element/]
-        }
-    };
+sub count_nested { return scalar @{ $_[0]->nested }; }
+
+sub has_nested { return $_[0]->count_nested ? 1 : 0; }
+
+sub get_last_nested { return $_[0]->nested->[ $_[0]->count_nested - 1 ]; }
+
+sub clear_last_nested {
+    return delete $_[0]->nested->[ $_[0]->count_nested - 1 ];
 }
 
-sub all_current_tables {
-    return @{ shift->current_tables };
-}
+sub all_current_tables { return @{ $_[0]->current_tables }; }
 
-sub count_current_tables {
-    return scalar @{ shift->current_tables };
-}
+sub count_current_tables { return scalar @{ $_[0]->current_tables }; }
 
-sub current_cell_index {
-    my $self = shift;
-
-    return scalar @{ $self->current_row->cells };
+sub current_or_nested {
+    return $_[0]->has_nested ? $_[0]->get_last_nested : $_[0]->current_table;
 }
 
 sub current_cell_header {
-    my $self = shift;
+    my ( $self, $current_cell ) = @_;
 
-    my $cell_index = $self->current_cell_index;
-    my $header     = $self->current_table->headers->[$cell_index];
+    my $table = $self->current_or_nested;
+    my $row   = $table->get_last_row;
+
+    my $header;
+    if ( $row->header ) {
+        $header = $row->header;
+    }
+    else {
+        my $cell_index = $table->get_last_row->cell_count;
+        $header = $table->headers->[$cell_index];
+    }
 
     return unless $header;
 
-    push @{ $header->cells }, $self->current_cell;
+    push @{ $header->cells }, $current_cell;
 
     return $header;
 }
@@ -121,10 +93,45 @@ sub start {
     $tag = lc $tag;
 
     if ( my $store_tag = $self->options->{$tag} ) {
-        my $class = 'HTML::TableContent::' . $store_tag->{class};
-        my $table = $class->new($attr);
-        for ( @{ $store_tag->{store} } ) {
-            $self->$_($table);
+        my $class   = $store_tag->{class};
+        my $element = $class->new($attr);
+
+        $self->current_element($element);
+
+        my $table = $self->current_or_nested;
+
+        if ( $tag eq 'th' ) {
+            $table->get_last_row->header($element);
+            push @{ $table->headers }, $element;
+        }
+        if ( $tag eq 'tr' ) {
+            push @{ $table->rows }, $element;
+        }
+        if ( $tag eq 'td' ) {
+            $element->header( $self->current_cell_header($element) );
+            push @{ $table->get_last_row->cells }, $element;
+        }
+
+        if ( $tag eq 'caption' ) {
+            $table->caption($element);
+        }
+
+        if ( $tag eq 'table' ) {
+            if ( defined $self->current_table
+                && $self->current_table->isa('HTML::TableContent::Table') )
+            {
+                if ( $self->has_nested ) {
+
+              # first table has all nested tables - $tp->get_first_table->nested
+                    push @{ $self->current_table->nested }, $element;
+                }
+                push @{ $self->nested },  $element;
+                push @{ $table->nested }, $element;
+                push @{ $table->get_last_row->get_last_cell->nested }, $element;
+            }
+            else {
+                $self->current_table($element);
+            }
         }
     }
 
@@ -136,6 +143,7 @@ sub text {
 
     if ( my $elem = $self->current_element ) {
         if ( $text =~ m{\S+}xms ) {
+            $text =~ s{^\s+|\s+$}{}g;
             push @{ $elem->data }, $text;
         }
     }
@@ -145,56 +153,67 @@ sub text {
 
 sub end {
     my ( $self, $tag, $origtext ) = @_;
+
     $tag = lc $tag;
 
-    if ( my $clear = $self->options->{$tag} ) {
-        my $push_action = $clear->{push_action};
-        $self->$push_action;
-        for ( @{ $clear->{clear} } ) {
-            my $clearer = 'clear_' . $_;
-            $self->$clearer;
+    if ( $tag eq 'table' ) {
+        if ( $self->has_nested ) {
+            $self->clear_last_nested;
+        }
+        else {
+            push @{ $self->current_tables }, $self->current_table;
+            $self->clear_current_table;
         }
     }
 
-    return;
-}
+    if ( $tag eq 'tr' ) {
+        my $table =
+          $self->has_nested ? $self->get_last_nested : $self->current_table;
 
-sub _push_table {
-    my $self = shift;
-    if ( defined $self->current_table ) {
-        push @{ $self->current_tables }, $self->current_table;
+        my $row = $table->get_last_row;
+
+        if ( $row->cell_count == 0 ) {
+            $table->clear_last_row;
+        }
+
+        if ( $row->header ) {
+            $table->clear_last_row;
+
+            my $index = 0;
+            foreach my $cell ( $row->all_cells ) {
+                my $row = $table->rows->[$index];
+                if ( defined $row ) {
+                    push @{ $row->cells }, $cell;
+                }
+                else {
+                    my $new_row = HTML::TableContent::Table::Row->new();
+                    push @{ $new_row->cells }, $cell;
+                    push @{ $table->rows },    $new_row;
+                }
+                $index++;
+            }
+        }
     }
-    return;
 }
 
-sub _push_header {
-    my $self = shift;
-    if ( defined $self->current_header ) {
-        push @{ $self->current_table->headers }, $self->current_header;
-    }
-    return;
-}
-
-sub _push_row {
-    my $self = shift;
-    if ( defined $self->current_row && scalar @{ $self->current_row->cells } > 0) {
-        push @{ $self->current_table->rows }, $self->current_row;
-    }
-    return;
-}
-
-sub _push_cell {
-    my $self = shift;
-    if ( defined $self->current_cell ) {
-        $self->current_cell->header( $self->current_cell_header );
-        push @{ $self->current_row->cells }, $self->current_cell;
-    }
-    return;
-}
-
-sub _push_caption {
-    my $self = shift;
-    return $self->current_table->caption( $self->current_element );
+sub _build_options {
+    return {
+        table => {
+            class => 'HTML::TableContent::Table',
+        },
+        th => {
+            class => 'HTML::TableContent::Table::Header',
+        },
+        tr => {
+            class => 'HTML::TableContent::Table::Row',
+        },
+        td => {
+            class => 'HTML::TableContent::Table::Row::Cell',
+        },
+        caption => {
+            class => 'HTML::TableContent::Table::Caption',
+        }
+    };
 }
 
 1;
@@ -207,7 +226,7 @@ HTML::TableContent::Parser - HTML::Parser subclass.
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
