@@ -2,7 +2,7 @@ package HTML::TableContent::Table;
 
 use Moo;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 extends 'HTML::TableContent::Element';
 
@@ -14,37 +14,61 @@ has [qw(headers rows)] => (
     default => sub { [] },
 );
 
-sub all_rows {
-    return @{ shift->rows };
-}
+sub all_rows { return @{ $_[0]->rows }; }
 
-sub row_count {
-    return scalar @{ shift->rows };
-}
+sub row_count { return scalar @{ $_[0]->rows }; }
 
-sub get_row {
-    return shift->rows->[shift];
-}
+sub get_row { return $_[0]->rows->[ $_[1] ]; }
 
-sub get_first_row {
-    return shift->get_row(0);
-}
+sub get_first_row { return $_[0]->get_row(0); }
 
-sub all_headers {
-    return @{ shift->headers };
-}
+sub get_last_row { return $_[0]->get_row( $_[0]->row_count - 1 ); }
 
-sub header_count {
-    return scalar @{ shift->headers };
-}
+sub clear_last_row { return delete $_[0]->rows->[ $_[0]->row_count - 1 ]; }
 
-sub get_header {
-    return shift->headers->[shift];
-}
+sub all_headers { return @{ $_[0]->headers }; }
 
-sub get_first_header {
-    return shift->get_header(0);
-}
+sub header_count { return scalar @{ $_[0]->headers }; }
+
+sub get_header { return $_[0]->headers->[ $_[1] ]; }
+
+sub get_first_header { return $_[0]->get_header(0); }
+
+around has_nested => sub {
+    my ( $orig, $self ) = ( shift, shift );
+
+    my $nested = $self->$orig(@_);
+
+    my $row = $self->get_first_row;
+
+    for ( $row->all_cells ) {
+        if ( $_->has_nested ) {
+            $nested = 1;
+        }
+    }
+
+    return $nested;
+};
+
+around raw => sub {
+    my ( $orig, $self ) = ( shift, shift );
+
+    my $table = $self->$orig(@_);
+
+    if ( defined $self->caption ) { $table->{caption} = $self->caption->text }
+
+    $table->{headers} = [];
+    foreach my $header ( $self->all_headers ) {
+        push @{ $table->{headers} }, $header->raw;
+    }
+
+    $table->{rows} = [];
+    foreach my $row ( $self->all_rows ) {
+        push @{ $table->{rows} }, $row->raw;
+    }
+
+    return $table;
+};
 
 sub headers_spec {
     my $self = shift;
@@ -63,18 +87,18 @@ sub header_exists {
 }
 
 sub get_col {
-    my ($self, $col) = @_;
+    my ( $self, $col ) = @_;
 
     my %args = ( header => $col );
     return $self->get_header_column(%args);
 }
 
 sub get_col_text {
-    my ($self, $col) = @_;
+    my ( $self, $col ) = @_;
 
     my %args = ( header => $col );
     return $self->get_header_column_text(%args);
-}   
+}
 
 sub get_header_column {
     my ( $self, %args ) = @_;
@@ -103,6 +127,29 @@ sub get_header_column_text {
     return \@cell_text;
 }
 
+sub has_nested_table_column {
+    my $self = shift;
+    for my $header ( $self->all_headers ) {
+        for ( $header->all_cells ) {
+            return 1 if $_->has_nested;
+        }
+    }
+    return 0;
+}
+
+sub nested_column_headers {
+    my $self = shift;
+
+    my $columns = {};
+    for my $header ( $self->all_headers ) {
+        my $cell = $header->get_first_cell;
+        if ( $cell->has_nested ) {
+            $columns->{ $header->lc_text }++;
+        }
+    }
+    return $columns;
+}
+
 sub _dedupe_object_array_not_losing_order {
     my ( $self, @items ) = @_;
 
@@ -119,26 +166,6 @@ sub _dedupe_object_array_not_losing_order {
     return @new_items;
 }
 
-around raw => sub {
-    my ( $orig, $self ) = ( shift, shift );
-
-    my $table = $self->$orig(@_);
-
-    if ( defined $self->caption ) { $table->{caption} = $self->caption->text }
-
-    $table->{headers} = [];
-    foreach my $header ( $self->all_headers ) {
-        push @{ $table->{headers} }, $header->raw;
-    }
-
-    $table->{rows} = [];
-    foreach my $row ( $self->all_rows ) {
-        push @{ $table->{rows} }, $row->raw;
-    }
-
-    return $table;
-};
-
 sub _filter_headers {
     my ( $self, @headers ) = @_;
 
@@ -172,7 +199,7 @@ HTML::TableContent::Table - Base class for table's
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
