@@ -2,7 +2,7 @@ package HTML::TableContent::Table::Row;
 
 use Moo;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 extends 'HTML::TableContent::Element';
 
@@ -12,21 +12,20 @@ has cells => (
     default => sub { [] },
 );
 
-sub cell_count {
-    return scalar @{ shift->cells };
-}
+has header => (
+    is   => 'rw',
+    lazy => 1,
+);
 
-sub all_cells {
-    return @{ shift->cells };
-}
+sub cell_count { return scalar @{ $_[0]->cells }; }
 
-sub get_cell {
-    return shift->cells->[shift];
-}
+sub all_cells { return @{ $_[0]->cells }; }
 
-sub get_first_cell {
-    return shift->get_cell(0);
-}
+sub get_cell { return $_[0]->cells->[ $_[1] ]; }
+
+sub get_first_cell { return $_[0]->get_cell(0); }
+
+sub get_last_cell { return $_[0]->get_cell( $_[0]->cell_count - 1 ); }
 
 sub _filter_headers {
     my ( $self, $headers ) = @_;
@@ -53,6 +52,20 @@ around raw => sub {
     return $row;
 };
 
+around has_nested => sub {
+    my ( $orig, $self ) = ( shift, shift );
+
+    my $nested = $self->$orig(@_);
+
+    foreach my $cell ( $self->all_cells ) {
+        if ( $cell->has_nested ) {
+            $nested = 1;
+        }
+    }
+
+    return $nested;
+};
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -65,7 +78,7 @@ HTML::TableContent::Table::Row - base class for table rows.
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =head1 SYNOPSIS
 
